@@ -1,37 +1,20 @@
 package MooseX::Constructor::AllErrors;
-our $VERSION = '0.008';
-
-
-
-use strict;
-use warnings;
+our $VERSION = '0.009';
 
 use Moose ();
 use Moose::Exporter;
-use Moose::Util::MetaRole;
-use MooseX::Constructor::AllErrors::Role::Object;
-use MooseX::Constructor::AllErrors::Role::Meta::Method::Constructor;
 
-Moose::Exporter->setup_import_methods;
+use MooseX::Constructor::AllErrors::Error;
+use MooseX::Constructor::AllErrors::Error::Constructor;
+use MooseX::Constructor::AllErrors::Error::Required;
+use MooseX::Constructor::AllErrors::Error::TypeConstraint;
 
-sub init_meta {
-  shift;
-  my %options = @_;
-
-  Moose->init_meta(%options);
-
-  Moose::Util::MetaRole::apply_base_class_roles(
-    for_class => $options{for_class},
-    roles => [ 'MooseX::Constructor::AllErrors::Role::Object' ],
-  );
-
-  Moose::Util::MetaRole::apply_metaclass_roles(
-    for_class => $options{for_class},
+Moose::Exporter->setup_import_methods(
+    base_class_roles => [ 'MooseX::Constructor::AllErrors::Role::Object' ],
     constructor_class_roles => [
       'MooseX::Constructor::AllErrors::Role::Meta::Method::Constructor',
     ],
-  );
-}
+);
 
 1;
 
@@ -43,14 +26,11 @@ MooseX::Constructor::AllErrors - capture all constructor errors
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
   package MyClass;
-our $VERSION = '0.008';
-
-
   use MooseX::Constructor::AllErrors;
 
   has foo => (is => 'ro', required => 1);
@@ -70,12 +50,6 @@ If there are errors, C<$@> will contain a
 L<MooseX::Constructor::AllErrors::Error::Constructor> object.  See its
 documentation for possible error types.
 
-=begin Pod::Coverage
-
-init_meta
-
-=end Pod::Coverage
-
 =head1 SEE ALSO
 
 L<Moose>
