@@ -1,4 +1,5 @@
 package MooseX::Constructor::AllErrors::Error::Constructor;
+our $VERSION = '0.009';
 
 use Moose;
 
@@ -75,6 +76,10 @@ __END__
 
 MooseX::Constructor::AllErrors::Error::Constructor - error class for MooseX::Constructor::AllErrors
 
+=head1 VERSION
+
+version 0.009
+
 =head1 DESCRIPTION
 
 C<$@> will contain an instance of this class when
@@ -83,35 +88,17 @@ construction.
 
 =head1 METHODS
 
-=head2 has_errors
-
-True if there are any errors.
-
-=head2 add_error
-
-Push a new error to the list (should be an
-L<MooseX::Constructor::AllErrors::Error> object).
-
-=head2 message
-
-Returns the first error message found.
-
-=head2 stringify
-
-Returns the first error message found, along with caller information (filename
-and line number).
-
 =head2 errors
 
 Returns a list of L<MooseX::Constructor::AllErrors::Error> objects representing
 each error that was found.
 
-=head2 missing
+=head2 invalid
 
 Returns a list of L<MooseX::Constructor::AllErrors::Error::Required> objects
 representing each missing argument error that was found.
 
-=head2 invalid
+=head2 missing
 
 Returns a list of L<MooseX::Constructor::AllErrors::Error::TypeConstraint>
 objects representing each type constraint error that was found.
@@ -130,4 +117,4 @@ This software is copyright (c) 2009 by Hans Dieter Pearcey. This is free
 software; you can redistribute it and/or modify it under the same terms as perl
 itself. 
 
-=cut
+=cut
\ No newline at end of file
